from setuptools import setup, find_packages

VERSION = "0.0.1"
DESCRIPTION = "test package."

setup(
    name="testpackage_gokuruto",
    version=VERSION,
    autor="MP",
    description=DESCRIPTION,
    packages=find_packages(),
    install_requires=[],
    keywords=["python"]
)
